==> jupyterlab-optumi-3.9.5.tar.gz: jupyterlab-optumi-3.9.5/src/models/Package.ts <==
/*
**  Copyright (C) Optumi Inc - All rights reserved.
**
**  You may only use this code under license with Optumi Inc and any distribution or modification is strictly prohibited.
**  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
**/

import { OptumiConfig } from "./OptumiConfig"

export enum PackageState {
	ACCEPTED = "accepted",
    SHIPPED = "shipped",
    OPENED = "opened",
    CANCELED = "canceled",
}

export class Package {
    public timestamp: Date
    public nbKey: string
    public label: string
    public packageState: string
    public originalNotebook: any
    public originalConfig: OptumiConfig
    public optimizedNotebook: any
    public optimizedConfig: OptumiConfig

    constructor(timestamp: Date, nbKey: string, label: string, packageState: PackageState, originalNotebook: any, originalConfig: OptumiConfig, optimizedNotebook: any, optimizedConfig: OptumiConfig) {
        this.timestamp = timestamp;
        this.nbKey = nbKey;
        this.label = label;
        this.packageState = packageState;
        this.originalNotebook = originalNotebook;
        this.originalConfig = originalConfig;
        this.optimizedNotebook = optimizedNotebook;
        this.optimizedConfig = optimizedConfig;
    }

    public update(pack: Package) {
        this.timestamp = pack.timestamp;
        this.nbKey = pack.nbKey;
        this.label = pack.label;
        this.packageState = pack.packageState;
        this.originalNotebook = pack.originalNotebook;
        this.originalConfig = pack.originalConfig;
        this.optimizedNotebook = pack.optimizedNotebook;
        this.optimizedConfig = pack.optimizedConfig;
    }

    static fromMap(map: any = {}): Package {
        return new Package(new Date(map.timestamp), map.nbKey, map.label, map.packageState as PackageState, 
            map.originalNotebook ? JSON.parse(map.originalNotebook) : null, 
            map.originalConfig ? new OptumiConfig(JSON.parse(map.originalConfig)) : null, 
            map.optimizedNotebook ? JSON.parse(map.optimizedNotebook) : null, 
            map.optimizedConfig ? new OptumiConfig(JSON.parse(map.optimizedConfig)) : null);
    }
}

==> jupyterlab-optumi-3.9.6.tar.gz: jupyterlab-optumi-3.9.6/src/models/Package.ts <==
/*
**  Copyright (C) Optumi Inc - All rights reserved.
**
**  You may only use this code under license with Optumi Inc and any distribution or modification is strictly prohibited.
**  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
**/

import { OptumiConfig } from "./OptumiConfig"

export enum PackageState {
	ACCEPTED = "accepted",
    SHIPPED = "shipped",
    OPENED = "opened",
    CANCELED = "canceled",
}

export class Package {
    public timestamp: Date
    public nbKey: string
    public label: string
    public packageState: string
    public originalNotebook: any
    public originalConfig: OptumiConfig
    public optimizedNotebook: any
    public optimizedConfig: OptumiConfig
    public auto: boolean

    constructor(timestamp: Date, nbKey: string, label: string, packageState: PackageState, originalNotebook: any, originalConfig: OptumiConfig, optimizedNotebook: any, optimizedConfig: OptumiConfig, auto: boolean) {
        this.timestamp = timestamp;
        this.nbKey = nbKey;
        this.label = label;
        this.packageState = packageState;
        this.originalNotebook = originalNotebook;
        this.originalConfig = originalConfig;
        this.optimizedNotebook = optimizedNotebook;
        this.optimizedConfig = optimizedConfig;
        this.auto = auto;
    }

    public update(pack: Package) {
        this.timestamp = pack.timestamp;
        this.nbKey = pack.nbKey;
        this.label = pack.label;
        this.packageState = pack.packageState;
        this.originalNotebook = pack.originalNotebook;
        this.originalConfig = pack.originalConfig;
        this.optimizedNotebook = pack.optimizedNotebook;
        this.optimizedConfig = pack.optimizedConfig;
        this.auto = pack.auto;
    }

    static fromMap(map: any = {}): Package {
        return new Package(new Date(map.timestamp), map.nbKey, map.label, map.packageState as PackageState, 
            map.originalNotebook ? JSON.parse(map.originalNotebook) : null, 
            map.originalConfig ? new OptumiConfig(JSON.parse(map.originalConfig)) : null, 
            map.optimizedNotebook ? JSON.parse(map.optimizedNotebook) : null, 
            map.optimizedConfig ? new OptumiConfig(JSON.parse(map.optimizedConfig)) : null,
            map.auto == undefined ? false : map.auto);
    }
}
